import { get, post, put } from "@/utils/requestMethod";

/**
 * 获取公司基本信息
 * @returns
 */
const getCompanyBasicInfo = () => {
  return get(`/data/company`);
};

/**
 * 修改公司基本信息
 * @param {*} options
 * @returns
 */
const editCompanyBasicInfo = (options) => {
  let params = new FormData();
  options.management_unit &&
    options.management_unit !== "" &&
    params.append("management_unit", options.management_unit);
  options.custodian_unit &&
    options.custodian_unit !== "" &&
    params.append("custodian_unit", options.custodian_unit);
  options.introduction &&
    options.introduction !== "" &&
    params.append("introduction", options.introduction);
  options.contact_person &&
    options.contact_person !== "" &&
    params.append("contact_person", options.contact_person);
  options.contact_information &&
    options.contact_information !== "" &&
    params.append("contact_information", options.contact_information);
  options.picture &&
    options.picture !== "" &&
    params.append("picture", options.picture);
  return put("/data/company", params);
};

/**
 * 获取楼宇列表
 * @param {*} page
 * @param {*} page_size
 * @param {*} template_type
 * @param {*} template_name
 * @param {*} template_format
 * @returns
 */

const getBuildingList = () => {
  return get(`/data/building_list`);
};

/**
 * 添加楼宇接口 -- 经测试接口有问题
 * @param {*} options
 * @returns
 */
const addBuilding = (options) => {
  let params = new FormData();
  options.building_name &&
    options.building_name !== "" &&
    params.append("building_name", options.building_name);
  options.building_area &&
    options.building_area !== "" &&
    params.append("building_area", options.building_area);
  options.building_floor &&
    options.building_floor !== "" &&
    params.append("building_floor", options.building_floor);
  options.trem && options.trem !== "" && params.append("trem", options.trem);
  options.date && options.date !== "" && params.append("date", options.date);
  options.contact_person &&
    options.contact_person !== "" &&
    params.append("contact_person", options.contact_person);
  options.contact_information &&
    options.contact_information !== "" &&
    params.append("contact_information", options.contact_information);
  options.building_introduction &&
    options.building_introduction !== "" &&
    params.append("building_introduction", options.building_introduction);
  return post("/data/building", params);
};

/**
 * 获取底层系统
 * @param {*} page
 * @param {*} page_size
 * @returns
 */
const getUnderlyingSystem = () => {
  return get(`/data/underlying_system`);
};

/**
 * 添加底层系统
 * @param {*} picture
 * @returns
 */
const addUnderlyingSystem = (picture) => {
  let params = new FormData();
  return post(`/data/underlying_system`, params);
};

export {
  addUnderlyingSystem,
  getCompanyBasicInfo,
  editCompanyBasicInfo,
  getBuildingList,
};
